[![Build Status](https://github.com/dbbs-lab/bsb-yaml/actions/workflows/main.yml/badge.svg)](https://github.com/dbbs-lab/bsb-yaml/actions/workflows/main.yml)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)

# bsb-yaml

`bsb-yaml` is a plugin of the [BSB](https://github.com/dbbs-lab/bsb). 
It allows the user to write their models' configuration in the yaml format.
